<?php


class Post
{
	protected $db;
	protected $init_db = false;

	private $id;
	private $title;
	private $content;
	private $perex;
	private $visibility;
	private $created;
	private $read_count;
	private $og_title;
	private $og_description;
	private $img;
	private $url;
	
	private $next;
	private $prev;

	public function __construct($db)
	{
		$this->db = $db;

		if($this->init_db)
		{
			$this->init_db();
		}
	}


	public function add_post($title,$content,$perex,$visibility,$og_title = false, $og_description = false, $img = false,$url = false)
	{
		$data = array();
		$data['title'] = $title;
		$data['content'] = $content;
		$data['content_raw'] = strip_tags($content);
		$data['perex'] = $perex;
		$data['read_count'] = 0;
		$data['perex_raw'] = strip_tags($perex);
		$data['visibility'] = $visibility;
		$data['created'] = get_today_date();
		$data['og_title'] = (isset($og_title) && !empty($og_title) ? $og_title : $title);
		$data['og_description'] = (isset($og_description) && !empty($og_description) ? $og_description : null);
		$data['img'] = (isset($img) && !empty($img) ? $img : null );
		$data['url'] = (isset($url) && !empty($url) ? friendly_string($url) : friendly_string($title));

		// Control exist url
		$url = $this->db->query("SELECT url FROM posts WHERE url = '$data[url]' ORDER BY id",true)->fetch();
		if($this->db->getRows() > 0){
			$set_new_url = false;
			$i = 2;
			while(!$set_new_url){
				$url = $data['url'].'-'.$i;

				$new_url = $this->db->query("SELECT url FROM posts WHERE url = '$url' ORDER BY id",true)->fetch();

				if($this->db->getRows() == 0){ 
					$set_new_url = true;
					$data['url'] = $url;
				}

				$i++;
			}
		}
		$this->db->insert('posts',$data);
	}
	public function edit_post($id,$title,$content,$perex,$visibility,$og_title = false, $og_description = false, $img = false,$url = false)
	{
		$data = array();
		$data['title'] = $title;
		$data['content'] = $content;
		$data['content_raw'] = strip_tags($content);
		$data['perex'] = $perex;
		$data['perex_raw'] = strip_tags($perex);
		$data['visibility'] = $visibility;
		$data['og_title'] = (isset($og_title) && !empty($og_title) ? $og_title : $title);
		$data['og_description'] = (isset($og_description) && !empty($og_description) ? $og_description : null);
		$data['img'] = (isset($img) && !empty($img) ? $img : null );
		$data['url'] = (isset($url) && !empty($url) ? friendly_string($url) : friendly_string($title));

		// Control exist url
		$url = $this->db->query("SELECT url FROM posts WHERE url = '$data[url]' AND id != '$id' ORDER BY id",true)->fetch();
		if($this->db->getRows() > 0){
			$set_new_url = false;
			$i = 2;
			while(!$set_new_url){
				$url = $data['url'].'-'.$i;

				$new_url = $this->db->query("SELECT url FROM posts WHERE url = '$url' ORDER BY id",true)->fetch();

				if($this->db->getRows() == 0){ 
					$set_new_url = true;
					$data['url'] = $url;
				}

				$i++;
			}
		}
		$this->db->update('posts', $data, array('id'=>$id));
	}

	public function can_load_more($date)
	{
		if($posts = $this->db->query("SELECT id FROM posts WHERE created < '$date'")->fetch())
			return true;
		else
			return false;
	}
	public function all_posts($count = 0,$defaultLimit = 6)
	{
		if($count === 'all'){
			return	$posts = $this->db->query("SELECT * FROM posts ORDER BY created DESC")->fetch();
		}else{
			$offset = (int)($count / $defaultLimit) * $defaultLimit;
			return	$posts = $this->db->query("SELECT * FROM posts WHERE visibility = 'public' ORDER BY created DESC LIMIT $defaultLimit OFFSET $offset ")->fetch();
		}
	}
	public function remove_post($data)
	{
		if(is_array($data)){
			foreach ($data as $key => $value) {
				$new_url = $this->db->query("DELETE FROM `posts` WHERE `id`='$value';",true);
			}
		}else{
			$new_url = $this->db->query("DELETE FROM `posts` WHERE `id`='$data';",true);

		}
	}

	public function add_count($id)
	{
		if(is_numeric($id) and intval($id) == $id){
			$post = $this->db->query("UPDATE posts SET read_count = read_count + 1 WHERE id = '".(int)$id."'",true);
		}else{
			$post = $this->db->query("UPDATE posts SET read_count = read_count + 1 WHERE url = '$id'",true);
		}
	}
	public function load_post($id)
	{

		$id = $this->db->escape($id);
		if(is_numeric($id) and intval($id) == $id){
			$post = $this->db->query("SELECT * FROM posts WHERE id = '".(int)$id."'",true)->fetchSingle();
		}else{
			$post = $this->db->query("SELECT * FROM posts WHERE url = '$id'",true)->fetchSingle();
		}

		if($this->db->getRows() > 0){
			$this->id = $post['id'];
			$this->title = $post['title'];
			$this->content = $post['content'];
			$this->perex = $post['perex'];
			$this->visibility = $post['visibility'];
			$this->created = $post['created'];
			$this->read_count = $post['read_count'];
			$this->og_title = $post['og_title'];
			$this->og_description = $post['og_description'];
			$this->img = $post['img'];
			$this->url = $post['url'];

			$this->prev = $this->db->query("SELECT url FROM posts WHERE created > '$post[created]' ORDER BY created ASC LIMIT 1",true)->fetchSingle('url');

			$this->next = $this->db->query("SELECT url FROM posts WHERE created < '$post[created]' ORDER BY created DESC LIMIT 1",true)->fetchSingle('url');
			
			return true;
		}else{
			return false;
		}
	}

	public function search($value)
	{
		$value = lowercase(htmlspecialchars(strip_tags($value)));

		$sql = "SELECT 
		*
		FROM
		posts
		WHERE
		LOWER(content_raw) collate utf8_general_ci LIKE '%$value%'
		OR LOWER(perex_raw) collate utf8_general_ci LIKE '%$value%'
		OR LOWER(title) collate utf8_general_ci LIKE '%$value%'
		OR LOWER(url) collate utf8_general_ci LIKE '%$value%'
		ORDER BY created,read_count DESC
		";

		return $this->db->query($sql)->fetch();
	}


	private function init_db()
	{
		$sql = file_get_contents(BASE_DIR.'queries/blog.sql');
		$this->db->multi_query($sql);
	}

	public function get_id(){
		return $this->id;
	}
	public function get_title(){
		return $this->title;
	}
	public function get_content(){
		return $this->content;
	}
	public function get_perex(){
		return $this->perex;
	}
	public function get_visibility(){
		return $this->visibility;
	}
	public function get_created(){
		return $this->created;
	}
	public function get_read_count(){
		return $this->read_count;
	}
	public function get_og_title(){
		return $this->og_title;
	}
	public function get_og_description(){
		return $this->og_description;
	}
	public function get_img(){
		return $this->img;
	}
	public function get_url(){
		return $this->url;
	}
	public function get_next(){
		return $this->next;
	}
	public function get_prev(){
		return $this->prev;
	}


}